@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.4.7|
+|''Version''|1.4.10|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -42,10 +42,15 @@ adaptor.prototype.getStatus = function(context, userParams, callback) {
 };
 
 adaptor.getStatusCallback = function(status, context, responseText, uri, xhr) {
-	context.status = status;
-	context.statusText = xhr.statusText;
+	context.status = responseText ? status : false;
+	try {
+		context.statusText = xhr.statusText;
+	} catch(exc) { // offline (Firefox)
+		context.status = false;
+		context.statusText = null;
+	}
 	context.httpStatus = xhr.status;
-	if(status) {
+	if(context.status) {
 		context.serverStatus = $.evalJSON(responseText); // XXX: error handling!?
 	}
 	if(context.callback) {
@@ -320,7 +325,7 @@ adaptor.putTiddlerCallback = function(status, context, responseText, uri, xhr) {
 			var bag = loc.split("/bags/").pop().split("/")[0];
 			context.tiddler.fields["server.bag"] = bag;
 			context.tiddler.fields["server.workspace"] = "bags/" + bag;
-			var rev = etag.split("/").pop().split(";")[0];
+			var rev = etag.split("/").pop().split(/;|:/)[0];
 			context.tiddler.fields["server.page.revision"] = rev;
 			context.tiddler.fields["server.etag"] = etag;
 			if(context.callback) {
@@ -414,12 +419,12 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		}
 		// add new revision
 		var rev = $.extend({}, revisions[0]);
-		rev.title = to.title;
 		$.each(newTiddler, function(i, item) {
 			if(!$.isFunction(item)) {
 				rev[i] = item;
 			}
 		});
+		rev.title = to.title;
 		rev.created = rev.created.convertToYYYYMMDDHHMM();
 		rev.modified = new Date().convertToYYYYMMDDHHMM();
 		delete rev.fields.changecount;
